Set process phases in the StackSamplingProfiler.

BUG=657012

Review-Url: https://codereview.chromium.org/2530043002
Cr-Commit-Position: refs/heads/master@{#443394}
diff --git a/components/metrics/call_stack_profile_metrics_provider.h b/components/metrics/call_stack_profile_metrics_provider.h
index 74b096794..5c4f0db 100644
--- a/components/metrics/call_stack_profile_metrics_provider.h
+++ b/components/metrics/call_stack_profile_metrics_provider.h
@@ -19,10 +19,10 @@
 // Performs metrics logging for the stack sampling profiler.
 class CallStackProfileMetricsProvider : public MetricsProvider {
  public:
-  // These phases of a process lifetime can be passed as process "phases" to
-  // StackSmaplingProfile::SetProcessPhase(). Be sure to update the translation
-  // constants at the top of the .cc file when this is changed.
-  enum Phases : int {
+  // These milestones of a process lifetime can be passed as process "mile-
+  // stones" to StackSmaplingProfile::SetProcessMilestone(). Be sure to update
+  // the translation constants at the top of the .cc file when this is changed.
+  enum Milestones : int {
     MAIN_LOOP_START,
     MAIN_NAVIGATION_START,
     MAIN_NAVIGATION_FINISHED,
@@ -30,7 +30,7 @@
 
     SHUTDOWN_START,
 
-    PHASES_MAX_VALUE
+    MILESTONES_MAX_VALUE
   };
 
   CallStackProfileMetricsProvider();